<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>CreateBlock</name>
    <message>
        <location filename="../CreateBlock.js" line="+51"/>
        <source>Reference Point</source>
        <translatorcomment>--google--
Wskaż punkt odniesienia
Kopiuje obiekty do schowka z punktem odniesienia
Wycina obiekty z punktem odniesienia</translatorcomment>
        <translation>Punkt odniesienia</translation>
    </message>
    <message>
        <location filename="../CreateBlockInit.js" line="+2"/>
        <source>&amp;Create Block from Selection</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>&amp;Utwórz blok z zaznaczenia</translation>
    </message>
</context>
</TS>
